OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Neteisingas slaptažodis",
    "The new password can not be the same as the previous one" : "Naujas slaptažodis negali būti toks pats kaip ir ankstesnis",
    "No user supplied" : "Nepateiktas naudotojas",
    "Authentication error" : "Autentikacijos klaida",
    "Wrong admin recovery password. Please check the password and try again." : "Netinkamas administratoriau atkūrimo slaptažodis. Prašome pasitikrinti ir bandyti vėl.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Vartotojo slaptažodžio pakeitimas negalimas, bet šifravimo raktas atnaujintas sėkmingai.",
    "Unable to change password" : "Nepavyksta pakeisti slaptažodžio",
    "Couldn't send reset email. Please contact your administrator." : "Nepavyko išsiųsti atkūrimo laiško, susisiekite su administratoriumi.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "programų įrašymas ir atnaujinimas naudojantis programų parduotuve arba viešuoju debesiu",
    "Federated Cloud Sharing" : "Viešas dalijimasis debesiu",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL naudoja pasenusią %s versiją (%s). Pašome atnaujinti serverio operacinę sistemą arba serverio tarnybas, nes %s gali veikti netinkamai",
    "A problem occurred, please check your log files (Error: %s)" : "Iškilo problema, prašome peržiūrėti klaidų išrašus (Klaida: %s)",
    "Migration Completed" : "Migravimas baigtas",
    "Group already exists." : "Grupė jau egzistuoja.",
    "Unable to add group." : "Nepavyko pridėti grupės.",
    "Unable to delete group." : "Nepavyko ištrinti grupės.",
    "Saved" : "Išsaugoti",
    "test email settings" : "bandomojo laiško nustatymai",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Iškilo problema siunčiant bandomąjį laišką. Prašome peržiūrėti nustatymus. (Klaida: %s)",
    "Email sent" : "Laiškas išsiųstas",
    "You need to set your user email before being able to send test emails." : "Jūs privalote įvesti savo elektroniniu pašto adresą prieš siunčiant bandomąjį laišką.",
    "Invalid mail address" : "Neteisingas pašto adresas",
    "A user with that name already exists." : "Naudotojas tokiu vardu jau egzistuoja.",
    "Unable to create user." : "Nepavyko sukurti naudotojo.",
    "Your %s account was created" : "Tavo paskyra %s sukurta",
    "Unable to delete user." : "Nepavyko ištrinti naudotojo.",
    "Forbidden" : "Draudžiama",
    "Invalid user" : "Neteisingas naudotojas",
    "Unable to change mail address" : "Nepavyko pakeisti el. pašto adreso",
    "Your full name has been changed." : "Pilnas vardas pakeistas.",
    "Unable to change full name" : "Nepavyko pakeisti pilno vardo",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "Lietuvių",
    "Language changed" : "Kalba pakeista",
    "Invalid request" : "Klaidinga užklausa",
    "Admins can't remove themself from the admin group" : "Administratoriai negali pašalinti savęs iš administratorių grupės",
    "Couldn't remove app." : "Nepavyko pašalinti programėlės.",
    "Official" : "Oficiali",
    "Approved" : "Patvirtinta",
    "All" : "Viskas",
    "Enabled" : "Įjungta",
    "Not enabled" : "Neįjungta",
    "No apps found for your version" : "Jūsų versijai programų nėra",
    "Please wait...." : "Prašome palaukti...",
    "Error while disabling app" : "Klaida išjungiant programą",
    "Disable" : "Išjungti",
    "Enable" : "Įjungti",
    "Error while enabling app" : "Klaida įjungiant programą",
    "Updating...." : "Atnaujinama...",
    "Error while updating app" : "Įvyko klaida atnaujinant programą",
    "Updated" : "Atnaujinta",
    "Uninstalling ...." : "Ištinama...",
    "Error while uninstalling app" : "Klaida ištrinant programą",
    "Uninstall" : "Ištrinti",
    "Experimental" : "Eksperimentinė",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ar Jūs tikrai norite pridėti domeną \"{domain}\" į patikimų domenų sąrašą?",
    "Add trusted domain" : "Pridėti patikimą domeną",
    "Migration in progress. Please wait until the migration is finished" : "Vyksta migracija. Prašome palaukti, kol migracija bus pabaigta.",
    "Migration started …" : "Migravimas prasidėjo...",
    "Valid until {date}" : "Galioja iki {date}",
    "Delete" : "Ištrinti",
    "Disconnect" : "Atsijungti",
    "Sending..." : "Siunčiama...",
    "An error occurred: {message}" : "Įvyko klaida: {message}",
    "Select a profile picture" : "Pažymėkite profilio paveikslėlį",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "Groups" : "Grupės",
    "Unable to delete {objName}" : "Nepavyko ištrinti {objName}",
    "Error creating group: {message}" : "Klaida kuriant grupę: {message}",
    "A valid group name must be provided" : "Grupės pavadinimas turi būti tinkamas",
    "deleted {groupName}" : "{groupName} ištrinta",
    "undo" : "anuliuoti",
    "never" : "niekada",
    "deleted {userName}" : "{userName} ištrintas",
    "add group" : "pridėti grupę",
    "enabled" : "įjungtas",
    "disabled" : "išjungtas",
    "no group" : "grupės nėra",
    "Password successfully changed" : "Slaptažodis sėkmingai pakeistas",
    "A valid username must be provided" : "Vartotojo vardas turi būti tinkamas",
    "Error creating user: {message}" : "Klaida kuriant naudotoją: {message}",
    "A valid password must be provided" : "Slaptažodis turi būti tinkamas",
    "A valid email must be provided" : "El. pašto adresas turi būti tinkamas",
    "Cheers!" : "Sveikinimai!",
    "User documentation" : "Naudotojo dokumentacija",
    "Forum" : "Forumas",
    "by %s" : "%s",
    "Documentation:" : "Dokumentacija:",
    "Admin documentation" : "Administratoriaus dokumentacija",
    "Visit website" : "Aplankyti svetainę",
    "Report a bug" : "Pranešti apie klaidą",
    "Show description …" : "Rodyti aprašymą...",
    "Hide description …" : "Paslėpti aprašymą...",
    "Uninstall App" : "Ištinti programą",
    "Cron" : "Cron",
    "Open documentation" : "Atidaryti dokumentą",
    "Execute one task with each page loaded" : "Įvykdyti vieną užduotį su kiekvieno puslapio įkėlimu",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php yra registruotas tinklapio suplanuotų užduočių paslaugose, kad iškviesti cron.php kas 15 minučių per http.",
    "Valid until %s" : "Galioja iki %s",
    "Server-side encryption" : "Šifravimas serveryje",
    "Enable encryption" : "Įjungti šifravimą",
    "Start migration" : "Pradėti migravimą",
    "Sharing" : "Dalijimasis",
    "Allow apps to use the Share API" : "Leidžia programoms naudoti Share API",
    "Allow users to share via link" : "Leisti naudotojams dalintis nuoroda",
    "Allow public uploads" : "Leisti viešus įkėlimus",
    "Enforce password protection" : "Apsaugoti slaptažodžiu",
    "days" : "dienos",
    "Allow resharing" : "Leisti dalintis",
    "Errors and fatal issues" : "Klaidos ir kritinės problemos",
    "Fatal issues only" : "Tik kritinės problemos",
    "Log" : "Žurnalas",
    "What to log" : "Ką įtraukti į išrašą",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Išrašas didesnis nei 100 MB, todėl atsisiuntimas gali užtrukti.",
    "None" : "Nieko",
    "Login" : "Prisijungti",
    "Email server" : "Pašto serveris",
    "Encryption" : "Šifravimas",
    "From address" : "Nuo (el. paštas)",
    "Authentication method" : "Autentifikacijos metodas",
    "Authentication required" : "Reikalinga autentikacija",
    "Server address" : "Serverio adresas",
    "Port" : "Prievadas",
    "SMTP Username" : "SMTP naudotojo vardas",
    "SMTP Password" : "SMTP slaptažodis",
    "Store credentials" : "Išsaugoti prisijungimus",
    "Test email settings" : "Išbandyti el. pašto nustatymus",
    "Send email" : "Siųsti laišką",
    "Security & setup warnings" : "Saugos ir diegimo perspėjimai",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Trūksta PHP modulio „fileinfo“. Labai rekomenduojame įjungti šį modulį, kad gauti geriausius rezultatus nustatant mime-tipą.",
    "Tips & tricks" : "Patarimai ir gudrybės",
    "Get the apps to sync your files" : "Atsisiųskite programėlių, kad sinchronizuotumėte savo failus",
    "Desktop client" : "Darbastalio klientas",
    "Android app" : "Android programa",
    "iOS app" : "iOS programa",
    "Show First Run Wizard again" : "Rodyti pirmo karto vedlį dar kartą",
    "Profile picture" : "Profilio paveikslėlis",
    "Upload new" : "Įkelti naują",
    "Remove image" : "Pašalinti paveikslėlį",
    "png or jpg, max. 20 MB" : "png or jpg, max. 20 MB",
    "Cancel" : "Atšaukti",
    "Full name" : "Pilnas vardas",
    "Email" : "El. Paštas",
    "Your email address" : "Jūsų el. pašto adresas",
    "No email address set" : "Nenurodytas el. paštas",
    "You are member of the following groups:" : "Jūs priklausote šioms grupėms:",
    "Password" : "Slaptažodis",
    "Unable to change your password" : "Neįmanoma pakeisti slaptažodžio",
    "Current password" : "Dabartinis slaptažodis",
    "New password" : "Naujas slaptažodis",
    "Change password" : "Pakeisti slaptažodį",
    "Language" : "Kalba",
    "Help translate" : "Padėkite išversti",
    "Unlimited" : "Neribota",
    "Browser" : "Naršyklė",
    "Most recent activity" : "Vėliausia veikla",
    "Name" : "Pavadinimas",
    "App name" : "Programos pavadinimas",
    "Username" : "Prisijungimo vardas",
    "Done" : "Atlikta",
    "Version" : "Versija",
    "Personal" : "Asmeniniai",
    "Admin" : "Administravimas",
    "Error" : "Klaida",
    "Show storage location" : "Rodyti saugyklos vietą",
    "Send email to new user" : "Siųsti el. laišką naujiems naudotojams",
    "Show email address" : "Rodyti el. pašto adresą",
    "E-Mail" : "El. paštas",
    "Create" : "Sukurti",
    "Admin Recovery Password" : "Administracinis atkūrimo slaptažodis",
    "Enter the recovery password in order to recover the users files during password change" : "Įveskite atkūrimo slaptažodį, kad atkurti naudotojo failus keičiant slaptažodį",
    "Add Group" : "Pridėti grupę",
    "Group" : "Grupė",
    "Everyone" : "Visi",
    "Admins" : "Administratoriai",
    "Default Quota" : "Numatytoji kvota",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Įveskite vietos limitą (pvz.: \"512 MB\" arba \"12 GB\")",
    "Other" : "Kita",
    "Full Name" : "Pilnas vardas",
    "Group Admin for" : "Grupės administratorius",
    "Quota" : "Limitas",
    "Storage Location" : "Saugyklos vieta",
    "Last Login" : "Paskutinis prisijungimas",
    "change full name" : "keisti pilną vardą",
    "set new password" : "nustatyti naują slaptažodį",
    "change email address" : "pakeisti el. pašto adresą",
    "Default" : "Numatytasis",
    "Change" : "Keisti",
    "Share" : "Dalintis",
    "installing and updating apps via the market or Federated Cloud Sharing" : "diegiama ar atnaujinama aplikacijas per turgų arba Federated Cloud Sharing",
    "Allow users to send mail notification for shared files" : "Leisti naudotojams siųsti perspėjimus apie bendrinamus failus",
    "Domain" : "Domenas",
    "Add" : "Pridėti",
    "Allow sharing with groups" : "Leisti dalintis su grupėmis",
    "log-level out of allowed range" : "žurnalo lygis už rėžių",
    "Import root certificate" : "Įkelti pagrindinį sertifikatą",
    "Set default expiration date" : "Nustatykite galiojimo laiką",
    "%s password changed successfully" : "%sslaptažodis pakeistas",
    "Valid until" : "Galioja iki",
    "Expire after " : "Baigsis po",
    "Failed to change the email address." : "Nepavyko pakeisti el. pašto adreso",
    "Email has been changed successfully." : "El. pašto adresas sėkmingai pakeistas.",
    "The app will be downloaded from the app store" : "Applikacija bus atsiųsta iš parduotuvės",
    "Invalid email address" : "Neteisingas el.pašto adresas"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
